@@ -27,9 +27,10 @@ type TLSConfig struct {
 }
 
 type EventConfig struct {
-	Topics    nomad.Topics
-	Namespace string
-	JQQuery   *gojq.Code
+	Topics       nomad.Topics
+	Namespace    string
+	JQQuery      *gojq.Code
+	AllocJQQuery *gojq.Code
 }
 
 type LogConfig struct {
@@ -54,6 +55,7 @@ type Config struct {
 	StartAllTasksView             bool
 	CompactTables                 bool
 	StartFiltering                bool
+	FilterWithContext             bool
 }
 
 type Model struct {
@@ -170,17 +172,20 @@ func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 	case nomad.PageLoadedMsg:
 		if msg.Page == m.currentPage {
 			m.getCurrentPageModel().SetHeader(msg.TableHeader)
-			m.getCurrentPageModel().SetAllPageData(msg.AllPageRows)
+			m.getCurrentPageModel().SetAllPageRows(msg.AllPageRows)
 			if m.currentPageLoading() {
 				m.getCurrentPageModel().SetViewportXOffset(0)
 			}
+			if m.getCurrentPageModel().FilterWithContext {
+				m.getCurrentPageModel().ResetContextFilter()
+			}
 			m.getCurrentPageModel().SetLoading(false)
 
 			if m.currentPage.CanBeFirstPage() && len(msg.AllPageRows) == 0 {
 				// oddly, nomad http api errors when one provides the wrong token,
 				// but returns empty results when one provides an empty token
 				m.getCurrentPageModel().SetHeader([]string{"Error"})
-				m.getCurrentPageModel().SetAllPageData([]page.Row{
+				m.getCurrentPageModel().SetAllPageRows([]page.Row{
 					{"", "No results. Is the cluster empty or was no nomad token provided?"},
 					{"", "Press q or ctrl+c to quit."},
 				})
@@ -188,9 +193,12 @@ func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			}
 
 			switch m.currentPage {
-			case nomad.JobEventsPage, nomad.AllocEventsPage, nomad.AllEventsPage:
+			case nomad.JobEventsPage, nomad.AllEventsPage:
 				m.eventsStream = msg.EventsStream
 				cmds = append(cmds, nomad.ReadEventsStreamNextMessage(m.eventsStream, m.config.Event.JQQuery))
+			case nomad.AllocEventsPage:
+				m.eventsStream = msg.EventsStream
+				cmds = append(cmds, nomad.ReadEventsStreamNextMessage(m.eventsStream, m.config.Event.AllocJQQuery))
 			case nomad.LogsPage:
 				m.getCurrentPageModel().SetViewportSelectionToBottom()
 				if m.config.Log.Tail {
@@ -219,7 +227,11 @@ func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 					m.getCurrentPageModel().ScrollViewportToBottom()
 				}
 			}
-			cmds = append(cmds, nomad.ReadEventsStreamNextMessage(m.eventsStream, m.config.Event.JQQuery))
+			query := m.config.Event.JQQuery
+			if m.currentPage == nomad.AllocEventsPage {
+				query = m.config.Event.AllocJQQuery
+			}
+			cmds = append(cmds, nomad.ReadEventsStreamNextMessage(m.eventsStream, query))
 		}
 
 	case nomad.LogsStreamMsg:
@@ -327,7 +339,7 @@ func (m *Model) initialize() error {
 	m.pageModels = make(map[nomad.Page]*page.Model)
 	for k, pageConfig := range nomad.GetAllPageConfigs(m.width, m.getPageHeight(), m.config.CompactTables) {
 		startFiltering := m.config.StartFiltering && k == firstPage
-		p := page.New(pageConfig, m.config.CopySavePath, startFiltering)
+		p := page.New(pageConfig, m.config.CopySavePath, startFiltering, m.config.FilterWithContext)
 		m.pageModels[k] = &p
 	}
 
