@@ -5,6 +5,6 @@ rm -f $GOPATH/bin/wander
 echo "building $(date +"%T")"
 go build -o $thisdir/wander $thisdir/..
 if [ -f $thisdir/wander ]; then
-  mv $thisdir/wander $GOPATH/bin
+  mv $thisdir/wander $GOPATH/bin/wander
   echo "built"
 fi
